@@ -29,9 +29,9 @@ use crate::error::{BallistaError, Result as BResult};
 use crate::serde::scheduler::{Action, PartitionId};
 
 use arrow_flight;
-use arrow_flight::utils::flight_data_to_arrow_batch;
 use arrow_flight::Ticket;
-use arrow_flight::{flight_service_client::FlightServiceClient, FlightData};
+use arrow_flight::utils::flight_data_to_arrow_batch;
+use arrow_flight::{FlightData, flight_service_client::FlightServiceClient};
 use datafusion::arrow::array::ArrayRef;
 use datafusion::arrow::buffer::{Buffer, MutableBuffer};
 use datafusion::arrow::ipc::convert::try_schema_from_ipc_buffer;
@@ -45,7 +45,7 @@ use datafusion::error::DataFusionError;
 use datafusion::error::Result;
 
 use crate::serde::protobuf;
-use crate::utils::{create_grpc_client_connection, GrpcClientConfig};
+use crate::utils::{GrpcClientConfig, create_grpc_client_connection};
 use datafusion::physical_plan::{RecordBatchStream, SendableRecordBatchStream};
 use futures::{Stream, StreamExt};
 use log::{debug, warn};
@@ -361,6 +361,7 @@ pub struct BlockDataStream<S: Stream<Item = Result<prost::bytes::Bytes>> + Unpin
     state_buffer: Buffer,
     ipc_stream: S,
     transmitted: usize,
+    /// The schema of the data being streamed.
     pub schema: SchemaRef,
 }
 
@@ -368,6 +369,9 @@ pub struct BlockDataStream<S: Stream<Item = Result<prost::bytes::Bytes>> + Unpin
 const MAXIMUM_SCHEMA_BUFFER_SIZE: usize = 8_388_608;
 
 impl<S: Stream<Item = Result<prost::bytes::Bytes>> + Unpin> BlockDataStream<S> {
+    /// Creates a new `BlockDataStream` from the given IPC byte stream.
+    ///
+    /// Reads the schema from the stream header and initializes the decoder.
     pub async fn try_new(
         mut ipc_stream: S,
     ) -> std::result::Result<Self, DataFusionError> {
