@@ -20,8 +20,8 @@
 //! partition is re-partitioned and streamed to disk in Arrow IPC format. Future stages of the query
 //! will use the ShuffleReaderExec to read these results.
 
-use datafusion::arrow::ipc::writer::IpcWriteOptions;
 use datafusion::arrow::ipc::CompressionType;
+use datafusion::arrow::ipc::writer::IpcWriteOptions;
 
 use datafusion::arrow::ipc::writer::StreamWriter;
 use std::any::Any;
@@ -51,8 +51,8 @@ use datafusion::physical_plan::metrics::{
 };
 
 use datafusion::physical_plan::{
-    displayable, DisplayAs, DisplayFormatType, ExecutionPlan, Partitioning,
-    PlanProperties, SendableRecordBatchStream, Statistics,
+    DisplayAs, DisplayFormatType, ExecutionPlan, Partitioning, PlanProperties,
+    SendableRecordBatchStream, Statistics, displayable,
 };
 use futures::{StreamExt, TryFutureExt, TryStreamExt};
 
@@ -191,6 +191,7 @@ impl ShuffleWriterExec {
         self.shuffle_output_partitioning.as_ref()
     }
 
+    /// Executes the shuffle write operation for a single input partition.
     pub fn execute_shuffle_write(
         self,
         input_partition: usize,
@@ -359,12 +360,22 @@ impl DisplayAs for ShuffleWriterExec {
             DisplayFormatType::Default | DisplayFormatType::Verbose => {
                 write!(
                     f,
-                    "ShuffleWriterExec: partitioning:{:?}",
+                    "ShuffleWriterExec: partitioning: {}",
                     self.shuffle_output_partitioning
+                        .as_ref()
+                        .map(|p| p.to_string())
+                        .unwrap_or("None".to_string())
                 )
             }
             DisplayFormatType::TreeRender => {
-                write!(f, "partitioning={:?}", self.shuffle_output_partitioning)
+                write!(
+                    f,
+                    "partitioning={}",
+                    self.shuffle_output_partitioning
+                        .as_ref()
+                        .map(|p| p.to_string())
+                        .unwrap_or("None".to_string())
+                )
             }
         }
     }
