@@ -16,9 +16,10 @@
 // under the License.
 
 use crate::config::{
-    BallistaConfig, BALLISTA_GRPC_CLIENT_MAX_MESSAGE_SIZE, BALLISTA_JOB_NAME,
+    BALLISTA_GRPC_CLIENT_MAX_MESSAGE_SIZE, BALLISTA_JOB_NAME,
     BALLISTA_SHUFFLE_READER_FORCE_REMOTE_READ, BALLISTA_SHUFFLE_READER_MAX_REQUESTS,
     BALLISTA_SHUFFLE_READER_REMOTE_PREFER_FLIGHT, BALLISTA_STANDALONE_PARALLELISM,
+    BallistaConfig,
 };
 use crate::planner::BallistaQueryPlanner;
 use crate::serde::protobuf::KeyValuePair;
@@ -134,8 +135,10 @@ pub trait SessionConfigExt {
         max_requests: usize,
     ) -> Self;
 
+    /// Returns whether to prefer Flight protocol for remote shuffle reads.
     fn ballista_shuffle_reader_remote_prefer_flight(&self) -> bool;
 
+    /// Sets whether to prefer Flight protocol for remote shuffle reads.
     fn with_ballista_shuffle_reader_remote_prefer_flight(
         self,
         prefer_flight: bool,
@@ -563,8 +566,10 @@ mod test {
         let pairs = config.to_key_value_pairs();
 
         assert!(pairs.iter().any(|p| p.key == BALLISTA_JOB_NAME));
-        assert!(pairs
-            .iter()
-            .any(|p| p.key == "datafusion.catalog.information_schema"))
+        assert!(
+            pairs
+                .iter()
+                .any(|p| p.key == "datafusion.catalog.information_schema")
+        )
     }
 }
