@@ -15,22 +15,26 @@
 // specific language governing permissions and limitations
 // under the License.
 
+//! Pull-based task execution loop for the executor.
+//!
+//! This module implements the polling mechanism where executors actively
+//! request work from the scheduler, as opposed to push-based scheduling
+//! where the scheduler sends tasks to executors.
+
 use crate::cpu_bound_executor::DedicatedExecutor;
 use crate::executor::Executor;
 use crate::executor_process::remove_job_dir;
-use crate::{as_task_status, TaskExecutionTimes};
+use crate::{TaskExecutionTimes, as_task_status};
 use ballista_core::error::BallistaError;
 use ballista_core::extension::SessionConfigHelperExt;
+use ballista_core::serde::BallistaCodec;
 use ballista_core::serde::protobuf::{
-    scheduler_grpc_client::SchedulerGrpcClient, PollWorkParams, PollWorkResult,
-    TaskDefinition, TaskStatus,
+    PollWorkParams, PollWorkResult, TaskDefinition, TaskStatus,
+    scheduler_grpc_client::SchedulerGrpcClient,
 };
 use ballista_core::serde::scheduler::{ExecutorSpecification, PartitionId};
-use ballista_core::serde::BallistaCodec;
 use datafusion::execution::context::TaskContext;
-use datafusion::execution::SessionStateBuilder;
 use datafusion::physical_plan::ExecutionPlan;
-use datafusion::prelude::SessionContext;
 use datafusion_proto::logical_plan::AsLogicalPlan;
 use datafusion_proto::physical_plan::AsExecutionPlan;
 use futures::FutureExt;
@@ -38,13 +42,20 @@ use log::{debug, error, info, warn};
 use std::any::Any;
 use std::convert::TryInto;
 use std::error::Error;
-use std::ops::Deref;
 use std::sync::mpsc::{Receiver, Sender, TryRecvError};
 use std::time::{SystemTime, UNIX_EPOCH};
 use std::{sync::Arc, time::Duration};
 use tokio::sync::{OwnedSemaphorePermit, Semaphore};
 use tonic::transport::Channel;
 
+/// Main execution loop that polls the scheduler for available tasks.
+///
+/// This function runs indefinitely, periodically asking the scheduler for
+/// work. When tasks are received, they are executed on a dedicated thread
+/// pool and results are reported back to the scheduler.
+///
+/// The loop respects the executor's concurrent task limit via a semaphore,
+/// ensuring no more than the configured number of tasks run simultaneously.
 pub async fn poll_loop<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan>(
     mut scheduler: SchedulerGrpcClient<Channel>,
     executor: Arc<Executor>,
@@ -179,7 +190,9 @@ pub async fn poll_loop<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan>
                 }
             }
             Err(error) => {
-                warn!("Executor poll work loop failed. If this continues to happen the Scheduler might be marked as dead. Error: {error}");
+                warn!(
+                    "Executor poll work loop failed. If this continues to happen the Scheduler might be marked as dead. Error: {error}"
+                );
             }
         }
 
@@ -240,20 +253,6 @@ async fn run_received_task<T: 'static + AsLogicalPlan, U: 'static + AsExecutionP
 
     let runtime = executor.produce_runtime(&session_config)?;
 
-    // this is temporary fix until we get
-    // https://github.com/apache/datafusion/pull/17601
-    // merged
-    //
-    let session_state = SessionStateBuilder::new()
-        .with_aggregate_functions(task_aggregate_functions.values().cloned().collect())
-        .with_scalar_functions(task_scalar_functions.values().cloned().collect())
-        .with_window_functions(task_window_functions.values().cloned().collect())
-        .with_config(session_config.clone())
-        .with_runtime_env(runtime.clone())
-        .build();
-    let ctx = SessionContext::new_with_state(session_state);
-    //
-
     let session_id = task.session_id.clone();
     let task_context = Arc::new(TaskContext::new(
         Some(task_identity.clone()),
@@ -267,11 +266,7 @@ async fn run_received_task<T: 'static + AsLogicalPlan, U: 'static + AsExecutionP
 
     let plan: Arc<dyn ExecutionPlan> =
         U::try_decode(task.plan.as_slice()).and_then(|proto| {
-            proto.try_into_physical_plan(
-                &ctx,
-                runtime.deref(),
-                codec.physical_extension_codec(),
-            )
+            proto.try_into_physical_plan(&task_context, codec.physical_extension_codec())
         })?;
 
     let query_stage_exec = executor.execution_engine.create_query_stage_exec(
