@@ -36,10 +36,10 @@ use datafusion::common::config::ConfigOptions;
 use datafusion::common::error::Result;
 
 use datafusion::common::tree_node::{Transformed, TransformedResult, TreeNode};
-use datafusion::common::{internal_err, JoinSide, JoinType};
+use datafusion::common::{JoinSide, JoinType, internal_err};
 use datafusion::logical_expr::sort_properties::SortProperties;
-use datafusion::physical_expr::expressions::Column;
 use datafusion::physical_expr::LexOrdering;
+use datafusion::physical_expr::expressions::Column;
 use datafusion::physical_optimizer::PhysicalOptimizerRule;
 use datafusion::physical_plan::execution_plan::EmissionType;
 use datafusion::physical_plan::joins::utils::{ColumnIndex, JoinFilter};
@@ -544,19 +544,15 @@ pub fn hash_join_swap_subrule(
     mut input: Arc<dyn ExecutionPlan>,
     _config_options: &ConfigOptions,
 ) -> Result<Arc<dyn ExecutionPlan>> {
-    if let Some(hash_join) = input.as_any().downcast_ref::<HashJoinExec>() {
-        if hash_join.left.boundedness().is_unbounded()
-            && !hash_join.right.boundedness().is_unbounded()
-            && matches!(
-                *hash_join.join_type(),
-                JoinType::Inner
-                    | JoinType::Left
-                    | JoinType::LeftSemi
-                    | JoinType::LeftAnti
-            )
-        {
-            input = swap_join_according_to_unboundedness(hash_join)?;
-        }
+    if let Some(hash_join) = input.as_any().downcast_ref::<HashJoinExec>()
+        && hash_join.left.boundedness().is_unbounded()
+        && !hash_join.right.boundedness().is_unbounded()
+        && matches!(
+            *hash_join.join_type(),
+            JoinType::Inner | JoinType::Left | JoinType::LeftSemi | JoinType::LeftAnti
+        )
+    {
+        input = swap_join_according_to_unboundedness(hash_join)?;
     }
     Ok(input)
 }
@@ -612,14 +608,14 @@ mod test {
 
     use datafusion::{
         arrow::datatypes::{DataType, Field, Schema},
-        common::{stats::Precision, ColumnStatistics, JoinSide, JoinType, Statistics},
+        common::{ColumnStatistics, JoinSide, JoinType, Statistics, stats::Precision},
         config::ConfigOptions,
         logical_expr::Operator,
         physical_plan::{
+            ExecutionPlan,
             expressions::{BinaryExpr, Column},
             joins::utils::{ColumnIndex, JoinFilter},
             test::exec::StatisticsExec,
-            ExecutionPlan,
         },
     };
     //
