@@ -26,24 +26,29 @@ use ballista_core::{
     serde::scheduler::PartitionLocation,
 };
 use datafusion::config::ConfigOptions;
-use datafusion::physical_optimizer::enforce_sorting::EnforceSorting;
 use datafusion::physical_optimizer::PhysicalOptimizerRule;
+use datafusion::physical_optimizer::enforce_sorting::EnforceSorting;
 use datafusion::physical_plan::coalesce_partitions::CoalescePartitionsExec;
 use datafusion::physical_plan::repartition::RepartitionExec;
 use datafusion::physical_plan::sorts::sort_preserving_merge::SortPreservingMergeExec;
 use datafusion::physical_plan::{
-    with_new_children_if_necessary, ExecutionPlan, Partitioning,
+    ExecutionPlan, Partitioning, with_new_children_if_necessary,
 };
 
 use log::{debug, info};
 
 type PartialQueryStageResult = (Arc<dyn ExecutionPlan>, Vec<Arc<ShuffleWriterExec>>);
 
-/// [DistributedPlanner] breaks out plan into vector of stages
+/// Trait for breaking an execution plan into distributed query stages.
+///
+/// The planner creates a DAG of stages where each stage can be executed
+/// independently once its input stages are complete.
 pub trait DistributedPlanner {
-    /// Returns a vector of ExecutionPlans, where the root node is a [ShuffleWriterExec].
-    /// Plans that depend on the input of other plans will have leaf nodes of type [UnresolvedShuffleExec].
-    /// A [ShuffleWriterExec] is created whenever the partitioning changes.
+    /// Returns a vector of ExecutionPlans, where the root node is a [`ShuffleWriterExec`].
+    ///
+    /// Plans that depend on the input of other plans will have leaf nodes of type
+    /// [`UnresolvedShuffleExec`]. A [`ShuffleWriterExec`] is created whenever the
+    /// partitioning changes.
     fn plan_query_stages<'a>(
         &'a mut self,
         job_id: &'a str,
@@ -51,13 +56,19 @@ pub trait DistributedPlanner {
         config: &ConfigOptions,
     ) -> Result<Vec<Arc<ShuffleWriterExec>>>;
 }
-/// Default implementation of [DistributedPlanner]
+
+/// Default implementation of [`DistributedPlanner`].
+///
+/// Breaks execution plans into stages at shuffle boundaries (repartition, coalesce).
 pub struct DefaultDistributedPlanner {
+    /// Counter for generating unique stage IDs.
     next_stage_id: usize,
+    /// Optimizer rule for enforcing sort requirements after stage splitting.
     optimizer_enforce_sorting: EnforceSorting,
 }
 
 impl DefaultDistributedPlanner {
+    /// Creates a new `DefaultDistributedPlanner`.
     pub fn new() -> Self {
         Self {
             next_stage_id: 0,
@@ -202,7 +213,9 @@ fn create_unresolved_shuffle(
     ))
 }
 
-/// Returns the unresolved shuffles in the execution plan
+/// Returns all unresolved shuffle nodes in the execution plan.
+///
+/// Used to identify which input stages a plan depends on.
 pub fn find_unresolved_shuffles(
     plan: &Arc<dyn ExecutionPlan>,
 ) -> Result<Vec<UnresolvedShuffleExec>> {
@@ -222,6 +235,9 @@ pub fn find_unresolved_shuffles(
     }
 }
 
+/// Replaces [`UnresolvedShuffleExec`] nodes with [`ShuffleReaderExec`] nodes.
+///
+/// Called after input stages complete to connect stages with their actual partition locations.
 pub fn remove_unresolved_shuffles(
     stage: Arc<dyn ExecutionPlan>,
     partition_locations: &HashMap<usize, HashMap<usize, Vec<PartitionLocation>>>,
@@ -328,6 +344,7 @@ mod test {
     use ballista_core::execution_plans::{ShuffleWriterExec, UnresolvedShuffleExec};
     use ballista_core::serde::BallistaCodec;
     use datafusion::arrow::compute::SortOptions;
+    use datafusion::execution::TaskContext;
     use datafusion::physical_expr::expressions::Column;
     use datafusion::physical_plan::aggregates::{AggregateExec, AggregateMode};
     use datafusion::physical_plan::coalesce_batches::CoalesceBatchesExec;
@@ -337,13 +354,11 @@ mod test {
     use datafusion::physical_plan::sorts::sort::SortExec;
     use datafusion::physical_plan::sorts::sort_preserving_merge::SortPreservingMergeExec;
     use datafusion::physical_plan::windows::BoundedWindowAggExec;
-    use datafusion::physical_plan::{displayable, ExecutionPlan};
+    use datafusion::physical_plan::{ExecutionPlan, displayable};
     use datafusion::physical_plan::{InputOrderMode, Partitioning};
-    use datafusion::prelude::SessionContext;
     use datafusion_proto::physical_plan::AsExecutionPlan;
     use datafusion_proto::protobuf::LogicalPlanNode;
     use datafusion_proto::protobuf::PhysicalPlanNode;
-    use std::ops::Deref;
     use std::sync::Arc;
     use uuid::Uuid;
 
@@ -789,7 +804,8 @@ order by
         )?;
 
         let partial_hash = stages[0].children()[0].clone();
-        let partial_hash_serde = roundtrip_operator(&ctx, partial_hash.clone())?;
+        let partial_hash_serde =
+            roundtrip_operator(&ctx.task_ctx(), partial_hash.clone())?;
 
         let partial_hash = downcast_exec!(partial_hash, AggregateExec);
         let partial_hash_serde = downcast_exec!(partial_hash_serde, AggregateExec);
@@ -803,7 +819,7 @@ order by
     }
 
     fn roundtrip_operator(
-        ctx: &SessionContext,
+        ctx: &TaskContext,
         plan: Arc<dyn ExecutionPlan>,
     ) -> Result<Arc<dyn ExecutionPlan>, BallistaError> {
         let codec: BallistaCodec<LogicalPlanNode, PhysicalPlanNode> =
@@ -813,12 +829,8 @@ order by
                 plan.clone(),
                 codec.physical_extension_codec(),
             )?;
-        let runtime = ctx.runtime_env();
-        let result_exec_plan: Arc<dyn ExecutionPlan> = (proto).try_into_physical_plan(
-            ctx,
-            runtime.deref(),
-            codec.physical_extension_codec(),
-        )?;
+        let result_exec_plan: Arc<dyn ExecutionPlan> =
+            (proto).try_into_physical_plan(ctx, codec.physical_extension_codec())?;
         Ok(result_exec_plan)
     }
 }
