@@ -15,23 +15,27 @@
 # specific language governing permissions and limitations
 # under the License.
 
-# %% 
+# %%
 
 from ballista import BallistaBuilder
 from datafusion.context import SessionContext
 
-ctx: SessionContext = BallistaBuilder()\
-    .config("datafusion.catalog.information_schema","true")\
-    .config("ballista.job.name", "example ballista")\
+ctx: SessionContext = (
+    BallistaBuilder()
+    .config("datafusion.catalog.information_schema", "true")
+    .config("ballista.job.name", "example ballista")
     .standalone()
-    
+)
+
 
 ctx.sql("SELECT 1").show()
 
 # %%
 ctx.sql("SHOW TABLES").show()
 # %%
-ctx.sql("select name, value from information_schema.df_settings where name like 'ballista.job.name'").show()
+ctx.sql(
+    "select name, value from information_schema.df_settings where name like 'ballista.job.name'"
+).show()
 
 
 # %%
